package javax.swing.plaf.synth;

import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.beans.PropertyChangeEvent;
import java.awt.Graphics;
import javax.swing.text.Caret;
import java.awt.Insets;
import java.awt.Color;
import javax.swing.plaf.UIResource;
import javax.swing.text.JTextComponent;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import javax.swing.plaf.basic.BasicTextFieldUI;

public class SynthTextFieldUI extends BasicTextFieldUI implements SynthUI
{
    private SynthTextFieldUI.Handler handler;
    private SynthStyle style;
    
    public SynthTextFieldUI() {
        this.handler = new SynthTextFieldUI.Handler();
    }
    
    public static ComponentUI createUI(JComponent component) {
        return new SynthTextFieldUI();
    }
    
    private void updateStyle(JTextComponent textComponent) {
        SynthContext context = this.getContext(textComponent, 1);
        SynthStyle style = this.style;
        this.style = SynthLookAndFeel.updateStyle(context, this);
        if (this.style != style) {
            updateStyle(textComponent, context, this.getPropertyPrefix());
            if (style != null) {
                this.uninstallKeyboardActions();
                this.installKeyboardActions();
            }
        }
        context.dispose();
    }
    
    static void updateStyle(JTextComponent textComponent, SynthContext synthContext, String s) {
        SynthStyle style = synthContext.getStyle();
        Color caretColor = textComponent.getCaretColor();
        if (caretColor == null || caretColor instanceof UIResource) {
            textComponent.setCaretColor((Color)style.get(synthContext, s + ".caretForeground"));
        }
        Color foreground = textComponent.getForeground();
        if (foreground == null || foreground instanceof UIResource) {
            Color colorForState = style.getColorForState(synthContext, ColorType.TEXT_FOREGROUND);
            if (colorForState != null) {
                textComponent.setForeground(colorForState);
            }
        }
        Object value = style.get(synthContext, s + ".caretAspectRatio");
        if ((value instanceof Number)) {
            textComponent.putClientProperty("caretAspectRatio", value);
        }
        synthContext.setComponentState(768);
        Color selectionColor = textComponent.getSelectionColor();
        if (selectionColor == null || selectionColor instanceof UIResource) {
            textComponent.setSelectionColor(style.getColor(synthContext, ColorType.TEXT_BACKGROUND));
        }
        Color selectedTextColor = textComponent.getSelectedTextColor();
        if (selectedTextColor == null || selectedTextColor instanceof UIResource) {
            textComponent.setSelectedTextColor(style.getColor(synthContext, ColorType.TEXT_FOREGROUND));
        }
        synthContext.setComponentState(8);
        Color disabledTextColor = textComponent.getDisabledTextColor();
        if (disabledTextColor == null || disabledTextColor instanceof UIResource) {
            textComponent.setDisabledTextColor(style.getColor(synthContext, ColorType.TEXT_FOREGROUND));
        }
        Insets margin = textComponent.getMargin();
        if (margin == null || margin instanceof UIResource) {
            Insets empty_UIRESOURCE_INSETS = (Insets)style.get(synthContext, s + ".margin");
            if (empty_UIRESOURCE_INSETS == null) {
                empty_UIRESOURCE_INSETS = SynthLookAndFeel.EMPTY_UIRESOURCE_INSETS;
            }
            textComponent.setMargin(empty_UIRESOURCE_INSETS);
        }
        Caret caret = textComponent.getCaret();
        if ((caret instanceof UIResource)) {
            Object value2 = style.get(synthContext, s + ".caretBlinkRate");
            if (value2 != null && value2 instanceof Integer) {
                caret.setBlinkRate((int)value2);
            }
        }
    }
    
    @Override
    public SynthContext getContext(JComponent component) {
        return this.getContext(component, SynthLookAndFeel.getComponentState(component));
    }
    
    private SynthContext getContext(JComponent component, int n) {
        return SynthContext.getContext(component, this.style, n);
    }
    
    @Override
    public void update(Graphics graphics, JComponent component) {
        SynthContext context = this.getContext(component);
        SynthLookAndFeel.update(context, graphics);
        this.paintBackground(context, graphics, component);
        this.paint(context, graphics);
        context.dispose();
    }
    
    protected void paint(SynthContext synthContext, Graphics g) {
        super.paint(g, this.getComponent());
    }
    
    void paintBackground(SynthContext synthContext, Graphics graphics, JComponent component) {
        synthContext.getPainter().paintTextFieldBackground(synthContext, graphics, 0, 0, component.getWidth(), component.getHeight());
    }
    
    @Override
    public void paintBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        synthContext.getPainter().paintTextFieldBorder(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    protected void paintBackground(Graphics graphics) {
    }
    
    @Override
    protected void propertyChange(PropertyChangeEvent evt) {
        if (SynthLookAndFeel.shouldUpdateStyle(evt)) {
            this.updateStyle((JTextComponent)evt.getSource());
        }
        super.propertyChange(evt);
    }
    
    @Override
    protected void installDefaults() {
        super.installDefaults();
        this.updateStyle(this.getComponent());
        this.getComponent().addFocusListener(this.handler);
    }
    
    @Override
    protected void uninstallDefaults() {
        SynthContext context = this.getContext(this.getComponent(), 1);
        this.getComponent().putClientProperty("caretAspectRatio", null);
        this.getComponent().removeFocusListener(this.handler);
        this.style.uninstallDefaults(context);
        context.dispose();
        this.style = null;
        super.uninstallDefaults();
    }
    
    static JTextComponent access$100(SynthTextFieldUI synthTextFieldUI) {
        return synthTextFieldUI.getComponent();
    }
    
    static JTextComponent access$200(SynthTextFieldUI synthTextFieldUI) {
        return synthTextFieldUI.getComponent();
    }
    
    private final class Handler implements FocusListener
    {
        @Override
        public void focusGained(FocusEvent focusEvent) {
            SynthTextFieldUI.access$100(SynthTextFieldUI.this).repaint();
        }
        
        @Override
        public void focusLost(FocusEvent focusEvent) {
            SynthTextFieldUI.access$200(SynthTextFieldUI.this).repaint();
        }
    }
}
